<?php
/**
 * Perfect Plus Design Settings panel at Theme Customizer
 *
 * @package CodeVibrant
 * @subpackage Perfect Plus
 * @since 1.0.0
 */

add_action( 'customize_register', 'perfect_plus_design_settings_register' );

function perfect_plus_design_settings_register( $wp_customize ) {

    $wp_customize->register_control_type( 'Perfect_Plus_Customize_Control_Radio_Image' );

    /**
     * Add Design Settings Panel
     *
     * @since 1.0.0
     */
    $wp_customize->add_panel(
	    'perfect_plus_design_settings_panel',
	    array(
	        'priority'       => 20,
	        'capability'     => 'edit_theme_options',
	        'theme_supports' => '',
	        'title'          => __( 'Design Settings', 'perfect-plus' ),
	    )
    );

/*----------------------------------------------------------------------------------------------------------------------------------------*/
	/**
     * Archive section
     *
     * @since 1.0.0
     */
    $wp_customize->add_section(
        'perfect_plus_archive_section',
        array(
        	'priority'       => 5,
        	'panel'          => 'perfect_plus_design_settings_panel',
        	'capability'     => 'edit_theme_options',
        	'theme_supports' => '',
            'title'          => __( 'Archive Section', 'perfect-plus' )
        )
    );

    /**
     * Radio image field for archive sidebar
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'perfect_plus_archive_sidebar',
        array(
            'capability'        => 'edit_theme_options',
            'default'           => 'right_sidebar',
            'sanitize_callback' => 'perfect_plus_sanitize_select',
        )
    );
    $wp_customize->add_control( new Perfect_Plus_Customize_Control_Radio_Image(
        $wp_customize,
        'perfect_plus_archive_sidebar',
            array(
                'label'         => __( 'Archive Sidebars', 'perfect-plus' ),
                'description'   => __( 'Choose sidebar from available layouts', 'perfect-plus' ),
                'section'       => 'perfect_plus_archive_section',
                'settings'      => 'perfect_plus_archive_sidebar',
                'priority'      => 5,
                'choices'       => array(
                    'left_sidebar'      => array(
                        'label'         => __( 'Left Sidebar', 'perfect-plus' ),
                        'url'           => '%s/assets/images/left-sidebar.png'
                    ),
                    'right_sidebar'     => array(
                        'label'         => __( 'Right Sidebar', 'perfect-plus' ),
                        'url'           => '%s/assets/images/right-sidebar.png'
                    ),
                    'no_sidebar'        => array(
                        'label'         => __( 'No Sidebar', 'perfect-plus' ),
                        'url'           => '%s/assets/images/no-sidebar.png'
                    ),
                    'no_sidebar_center' => array(
                        'label'         => __( 'No Sidebar Center', 'perfect-plus' ),
                        'url'           => '%s/assets/images/no-sidebar-center.png'
                    )
                )
            )
        )
    );

/*----------------------------------------------------------------------------------------------------------------------------------------*/
    /**
     * Page Settings
     *
     * @since 1.0.0
     */
    $wp_customize->add_section(
        'perfect_plus_page_section',
        array(
            'priority'       => 10,
            'panel'          => 'perfect_plus_design_settings_panel',
            'capability'     => 'edit_theme_options',
            'theme_supports' => '',
            'title'          => __( 'Page Settings', 'perfect-plus' )
        )
    );      

    /**
     * Radio image field for page sidebar
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'perfect_plus_global_page_sidebar',
        array(
            'capability'        => 'edit_theme_options',
            'default'           => 'right_sidebar',
            'sanitize_callback' => 'perfect_plus_sanitize_select',
        )
    );
    $wp_customize->add_control( new Perfect_Plus_Customize_Control_Radio_Image(
        $wp_customize,
        'perfect_plus_global_page_sidebar',
            array(
                'label'         => __( 'Page Sidebars', 'perfect-plus' ),
                'description'   => __( 'Choose sidebar from available layouts', 'perfect-plus' ),
                'section'       => 'perfect_plus_page_section',
                'settings'      => 'perfect_plus_global_page_sidebar',
                'priority'      => 5,
                'choices'       => array(
                    'left_sidebar'      => array(
                        'label'         => __( 'Left Sidebar', 'perfect-plus' ),
                        'url'           => '%s/assets/images/left-sidebar.png'
                    ),
                    'right_sidebar'     => array(
                        'label'         => __( 'Right Sidebar', 'perfect-plus' ),
                        'url'           => '%s/assets/images/right-sidebar.png'
                    ),
                    'no_sidebar'        => array(
                        'label'         => __( 'No Sidebar', 'perfect-plus' ),
                        'url'           => '%s/assets/images/no-sidebar.png'
                    ),
                    'no_sidebar_center' => array(
                        'label'         => __( 'No Sidebar Center', 'perfect-plus' ),
                        'url'           => '%s/assets/images/no-sidebar-center.png'
                    )
                )
            )
        )
    );

/*----------------------------------------------------------------------------------------------------------------------------------------*/
    /**
     * Post Settings
     *
     * @since 1.0.0
     */
    $wp_customize->add_section(
        'perfect_plus_post_section',
        array(
            'priority'       => 15,
            'panel'          => 'perfect_plus_design_settings_panel',
            'capability'     => 'edit_theme_options',
            'theme_supports' => '',
            'title'          => __( 'Post Settings', 'perfect-plus' )
        )
    );      

    /**
     * Radio image field for page sidebar
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'perfect_plus_global_post_sidebar',
        array(
            'capability'        => 'edit_theme_options',
            'default'           => 'right_sidebar',
            'sanitize_callback' => 'perfect_plus_sanitize_select',
        )
    );
    $wp_customize->add_control( new Perfect_Plus_Customize_Control_Radio_Image(
        $wp_customize,
        'perfect_plus_global_post_sidebar',
            array(
                'label'         => __( 'Post Sidebars', 'perfect-plus' ),
                'description'   => __( 'Choose sidebar from available layouts', 'perfect-plus' ),
                'section'       => 'perfect_plus_post_section',
                'settings'      => 'perfect_plus_global_post_sidebar',
                'priority'      => 5,
                'choices'       => array(
                    'left_sidebar'      => array(
                        'label'         => __( 'Left Sidebar', 'perfect-plus' ),
                        'url'           => '%s/assets/images/left-sidebar.png'
                    ),
                    'right_sidebar'     => array(
                        'label'         => __( 'Right Sidebar', 'perfect-plus' ),
                        'url'           => '%s/assets/images/right-sidebar.png'
                    ),
                    'no_sidebar'        => array(
                        'label'         => __( 'No Sidebar', 'perfect-plus' ),
                        'url'           => '%s/assets/images/no-sidebar.png'
                    ),
                    'no_sidebar_center' => array(
                        'label'         => __( 'No Sidebar Center', 'perfect-plus' ),
                        'url'           => '%s/assets/images/no-sidebar-center.png'
                    )
                )
            )
        )
    );

}