<?php
/**
 * Perfect Header Settings panel at Theme Customizer
 *
 * @package CodeVibrant
 * @subpackage Perfect Plus
 * @since 1.0.0
 */

add_action( 'customize_register', 'perfect_plus_header_settings_register' );

function perfect_plus_header_settings_register( $wp_customize ) {

	$wp_customize->get_section( 'header_image' )->panel = 'perfect_plus_header_settings_panel';
	$wp_customize->get_section( 'header_image' )->title = __( 'Innerpages Header Image', 'perfect-plus' );
    $wp_customize->get_section( 'header_image' )->priority = '25';

    /**
     * Add General Settings Panel
     *
     * @since 1.0.0
     */
    $wp_customize->add_panel(
	    'perfect_plus_header_settings_panel',
	    array(
	        'priority'       => 10,
	        'capability'     => 'edit_theme_options',
	        'theme_supports' => '',
	        'title'          => __( 'Header Settings', 'perfect-plus' ),
	    )
    );

/*----------------------------------------------------------------------------------------------------------------------------------------*/
	/**
     * Top Header section
     *
     * @since 1.0.0
     */
    $wp_customize->add_section(
        'perfect_plus_top_header_section',
        array(
        	'priority'       => 5,
        	'panel'          => 'perfect_plus_header_settings_panel',
        	'capability'     => 'edit_theme_options',
        	'theme_supports' => '',
            'title'          => __( 'Top Header Section', 'perfect-plus' ),
            'description'    => __( 'Managed the content display at top header section.', 'perfect-plus' ),
        )
    );

    /**
     * Checkbox for show home content
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'top_header_option',
        array(
            'capability'        => 'edit_theme_options',
            'default'           => true,
            'sanitize_callback' => 'perfect_plus_sanitize_checkbox',
        )
    );
    $wp_customize->add_control( new Perfect_Plus_Toggle_Checkbox_Custom_Control(
        $wp_customize, 
        'top_header_option',
        array(
            'label'         => __( 'Top Header Section', 'perfect-plus' ),
            'description'   => __( 'Check this to show page content in Home page.', 'perfect-plus' ),
            'section'       => 'perfect_plus_top_header_section',
            'settings'      => 'top_header_option',
            'priority'      => 5
        )
    ));

    /**
     * Select field for left content
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'top_header_left_content',
        array(
            'capability'        => 'edit_theme_options',
            'default'           => 'social_icon',
            'sanitize_callback' => 'perfect_plus_sanitize_select',
        )
    );
    $wp_customize->add_control(
        'top_header_left_content',
        array(
            'label'         => __( 'Top Left Content', 'perfect-plus' ),
            'description'   => __( 'Choose content type for top header left side.', 'perfect-plus' ),
            'section'       => 'perfect_plus_top_header_section',
            'settings'      => 'top_header_left_content',
            'type'          => 'select',
            'priority'      => 10,
            'choices'       => array(
                'social_icon'   => __( 'Social Media', 'perfect-plus' ),
                'top_menu'      => __( 'Top Menu', 'perfect-plus' )
            )
        )
    );

    /**
     * Text field for phone
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'top_header_phone',
        array(
            'capability'        => 'edit_theme_options',
            'default'           => '',
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    $wp_customize->add_control(
        'top_header_phone',
        array(
            'label'         => __( 'Phone', 'perfect-plus' ),
            'section'       => 'perfect_plus_top_header_section',
            'settings'      => 'top_header_phone',
            'type'			=> 'text',
            'priority'      => 25
        )
    );

    /**
     * Text field for email
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'top_header_email',
        array(
            'capability'        => 'edit_theme_options',
            'default'           => '',
            'sanitize_callback' => 'sanitize_email',
        )
    );
    $wp_customize->add_control(
        'top_header_email',
        array(
            'label'         => __( 'Email', 'perfect-plus' ),
            'section'       => 'perfect_plus_top_header_section',
            'settings'      => 'top_header_email',
            'type'			=> 'text',
            'priority'      => 30
        )
    );

    /**
     * Text field for address
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'top_header_address',
        array(
            'capability'        => 'edit_theme_options',
            'default'           => '',
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    $wp_customize->add_control(
        'top_header_address',
        array(
            'label'         => __( 'Address', 'perfect-plus' ),
            'section'       => 'perfect_plus_top_header_section',
            'settings'      => 'top_header_address',
            'type'			=> 'text',
            'priority'      => 35
        )
    );

}