<?php
/**
 * Template part for displaying homepage service section.
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package CodeVibrant
 * @subpackage Perfect Plus
 * @since 1.0.0
 *
 */

$home_latest_blog_option = get_theme_mod( 'home_latest_blog_option', true );
if ( $home_latest_blog_option === false ) {
	return;
}
?>

<section id="cv-home-latest-blog" class="cv-home-section latest-blog-section clearfix">
	<div class="cv-container">

	<?php
		$section_title = get_theme_mod( 'home_latest_blog_title', __( 'Latest Blogs', 'perfect-plus' ) );
		if ( !empty( $section_title ) ) {
			$header_class = 'has-header';
		} else {
			$header_class = 'no-header';
		}
	?>
		<div class="section-header-wrapper <?php echo esc_attr( $header_class ); ?>">
			<?php if ( !empty( $section_title ) ) { ?><h2 class="cv-section-title"><?php echo esc_html( $section_title ); ?></h2><?php } ?>
		</div><!-- .section-header-wrapper -->

	<?php
		$latest_blog_cat_slugs = get_theme_mod( 'home_latest_blog_cat_slugs', '' );
		if ( !empty( $latest_blog_cat_slugs ) ) {
			$latest_blog_count  = apply_filters( 'perfect_plus_latest_blog_count', 3 );
			$read_more_btn_text = get_theme_mod( 'home_latest_blog_read_more_text', __( 'Discover', 'perfect-plus' ) );
			$latest_blog_args   = array(
	            'post_type' => 'post',
	            'category_name'  => esc_attr( $latest_blog_cat_slugs ),
	            'posts_per_page' => absint( $latest_blog_count )
	        );
	        $latest_blog_query = new WP_Query( $latest_blog_args );
	?>
			<div class="latest-posts-wrapper cv-column-wrapper">
	            <?php
	                if ( $latest_blog_query->have_posts() ) {
	                    $count = 2;
	                    while ( $latest_blog_query->have_posts() ) {
	                        $latest_blog_query->the_post();
	                        $wow_delay = ( $count/2 )-1+0.5;
	            ?>
	                    <div class="single-post-wrapper cv-column-3 wow fadeInUp" data-wow-delay="<?php echo esc_attr( $wow_delay ); ?>s">

	                        <div class="post-thumb-wrapper">
	                            <?php if ( has_post_thumbnail() ) { ?>
	                                <a href="<?php the_permalink(); ?>" title="<?php the_title_attribute(); ?>">
	                                    <?php the_post_thumbnail( 'medium_large' ); ?>
	                                </a>
	                            <?php } ?>
	                            <div class="post-meta-wrapper">
	                            	<div class="posted-date-wrap">
	                            		<span class="post-date"><?php the_time( esc_html_x( 'd', 'date format', 'perfect-plus' ) ); ?></span>
	                            		<span class="post-month"><?php the_time( esc_html_x( 'M', 'date format', 'perfect-plus' ) ); ?></span>
	                            	</div><!-- .posted-date-wrap -->
	                            </div><!-- .post-meta-wrapper -->
	                        </div><!-- .post-thumb-wrapper -->

	                        <div class="blog-content-wrapper">
	                            <h3 class="post-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>
	                            <div class="post-excerpt"><?php the_excerpt(); ?></div>
	                            <a class="news-more btn-more" href="<?php the_permalink(); ?>" title="<?php the_title_attribute(); ?>" ><?php echo esc_html( $read_more_btn_text ); ?></a>
	                        </div><!-- .blog-content-wrapper -->

	                    </div><!-- .single-post-wrapper -->
	            <?php
	                    $count++;
	                    }
	                }
	                wp_reset_postdata();
	            ?>
	        </div><!-- .latest-posts-wrapper -->
    <?php
    	}
    ?>

	</div><!-- .cv-container -->
</section><!-- #cv-home-latest-blog -->