<?php
/**
 * Template part for displaying homepage portfolio section.
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package CodeVibrant
 * @subpackage Perfect Plus
 * @since 1.0.0
 *
 */

$home_portfolio_option = get_theme_mod( 'home_portfolio_option', true );
if ( $home_portfolio_option === false ) {
	return;
}
?>

<section id="cv-home-portfolio" class="cv-home-section portfolio-section clearfix">
	<div class="cv-container">

	<?php
		$section_title = get_theme_mod( 'home_portfolio_title', __( 'Our Portfolio', 'perfect-plus' ) );
		if ( !empty( $section_title ) ) {
			$header_class = 'has-header';
		} else {
			$header_class = 'no-header';
		}
	?>
		<div class="section-header-wrapper <?php echo esc_attr( $header_class ); ?>">
			<?php if ( !empty( $section_title ) ) { ?><h2 class="cv-section-title"><?php echo esc_html( $section_title ); ?></h2><?php } ?>
		</div><!-- .section-header-wrapper -->

	<?php
		$section_cat_slugs = get_theme_mod( 'home_portfolio_cat_slugs', '' );
		if ( !empty( $section_cat_slugs ) ) {
			$section_portfolio_cat_array = explode( ',', $section_cat_slugs ) ;
			$filter_all_caption = apply_filters( 'perfect_plus_filter_all_caption', __( 'All', 'perfect-plus' ) );
	?>
			<div class="cv-portfolio-filter-list clearfix wow fadeInDown" data-wow-delay="0.5s">
				<ul class="portfolio-filter" id="filters">
					<li class="filter-item active">
                        <a href="#" data-filter="*"><?php echo esc_html( $filter_all_caption ); ?><i class="fa fa-check"> </i></a>
                    </li>
					<?php
						foreach ( $section_portfolio_cat_array as $key => $value ) {
							$get_cat_info = get_category_by_slug( $value );
							$get_cat_name = $get_cat_info->name;
						?>
							<li class="filter-item">
								<a href="#" data-filter=".cv-<?php echo esc_attr( $value ); ?>"><?php echo esc_html( $get_cat_name ); ?><i class="fa fa-check"> </i></a>
							</li>
						<?php
						}
					?>
				</ul>
			</div><!-- .cv-portfolio-filter-list -->

			<div class="cv-portfolio-posts-wrapper cv-column-wrapper">
				<?php
					$post_count = apply_filters( 'perfect_plus_portfolio_post_count', 6 );
					$portfolio_args = array(
						'category_name' => esc_attr( $section_cat_slugs ),
						'posts_per_page' => absint( $post_count )
					);
					$portfolio_query = new WP_Query( $portfolio_args );
					if ( $portfolio_query->have_posts() ) {
						$count = 2;
						while ( $portfolio_query->have_posts() ) {
							$portfolio_query->the_post();
							$get_categories = get_the_category();
							$category_slugs = "";
					 		$get_cat_slugs = array();

					 		foreach ( $get_categories as $cat_item ) {
					 			$get_cat_slugs[] = 'cv-'.$cat_item->slug;
					 		}
					 		$category_slugs = implode( " ", $get_cat_slugs );
					 		$wow_delay = ( $count/2 )-1+0.2;
				?>
							<div class="cv-single-item cv-column-3 item isotope-item cv-clearfix <?php echo esc_attr( $category_slugs ); ?> wow fadeInUp" data-wow-delay="<?php echo esc_attr( $wow_delay ); ?>s">
								<?php 
									if ( has_post_thumbnail() ) {
										echo '<div class="cv-image-holder">';
											the_post_thumbnail( 'medium_large' );
										echo '</div>';
									}
								?>
								<div class="cv-content-holder-wrap">
									<div class="cv-content-holder">
										<div class="cv-item-link"><a href="<?php the_permalink(); ?>"><i class="fa fa-link"></i></a></div>
										<h3 class="cv-item-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>
									</div>
								</div>
							</div><!-- .cv-single-item -->
				<?php
						$count++;
						}
					}
					wp_reset_postdata();
				?>
			</div><!-- .cv-portfolio-posts-wrapper -->
	<?php
		}
	?>

	</div><!-- .cv-container -->
</section><!-- #cv-home-portfolio -->